@@ -1,8 +1,8 @@
 #
 # -*- Perl -*-
-# $Id: msword.pl,v 1.28.4.3 2002/08/26 02:55:39 baba Exp $
+# $Id: msword.pl,v 1.28.4.11 2004/03/26 17:39:09 opengl2772 Exp $
 # Copyright (C) 1997-2000 Satoru Takabayashi All rights reserved.
-# Copyright (C) 2000 Satoru Takabayashi Namazu Project All rights reserved.
+#               2000-2004 Namazu Project All rights reserved.
 #     This is free software with ABSOLUTELY NO WARRANTY.
 #
 #  This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,6 @@
 package msword;
 use strict;
 use File::Basename;
-use File::Copy;
 require 'util.pl';
 require 'gfilter.pl';
 require 'html.pl';
@@ -110,6 +109,7 @@ sub filter_wv ($$$$$) {
     { 
 	my $fh = util::efopen("> $tmpfile");
 	print $fh $$cont;
+        util::fclose($fh);
     }
 
     $version = `$wordconvpath --version 2>/dev/null`;
@@ -126,9 +126,9 @@ sub filter_wv ($$$$$) {
     } else {
 	my $version = "unknown";
 	my $supported = undef;
-	my $fh_cmd = util::efopen("$wvversionpath $tmpfile |");
+	my $fh_cmd = util::efopen("$wvversionpath $tmpfile 2>/dev/null |");
 	while (<$fh_cmd>) {
-	    if (/^Version: (word\d+),/i) {
+	    if (/^Version: (word\d+)(?:,| )/i) {
 		$version = $1;
 		#
 		# Only word8 format is supported for Japanese.
@@ -138,8 +138,9 @@ sub filter_wv ($$$$$) {
 		}
 	    }
 	}
+        util::fclose($fh_cmd);
 	return _("Unsupported format: ") .  $version unless $supported;
-	system("$wordconvpath $options $tmpfile $ofile");
+	system("$wordconvpath $options $tmpfile $ofile 2>/dev/null");
         system("$utfconvpath -Iu8 -Oej $tmpfile2 > $tmpfile");
 	unlink($tmpfile2);
 	rename($tmpfile, $tmpfile2);
@@ -148,9 +149,11 @@ sub filter_wv ($$$$$) {
     {
 	my $fh = util::efopen("< $tmpfile2");
 	$$cont = util::readfile($fh);
+        util::fclose($fh);
+        codeconv::normalize_eucjp($cont);
 
 	# Exclude wvHtml's footer becaues it has no good index terms.
-	$$cont =~ s/<!--Section Ends-->.*$//s;
+        $$cont =~ s/(.*)<!--Section Ends-->.*$/$1/s;
     }
 
     unlink($tmpfile);
@@ -175,13 +178,18 @@ sub filter_doccat ($$$$$) {
  
     my $tmpfile  = util::tmpnam('NMZ.word');
     my $tmpfile2 = util::tmpnam('NMZ.word2');   
-    copy("$cfile", "$tmpfile2");
+    {
+        my $fh = util::efopen("> $tmpfile2");
+        print $fh $$cont;
+        util::fclose($fh);
+    }
 
     system("$wordconvpath -o e $tmpfile2 > $tmpfile");
 
     {
         my $fh = util::efopen("< $tmpfile");
         $$cont = util::readfile($fh);
+        util::fclose($fh);
     }
 
     unlink($tmpfile);
