@@ -1,8 +1,8 @@
 #
 # -*- Perl -*-
-# $Id: powerpoint.pl,v 1.6.4.1 2002/01/10 10:46:26 knok Exp $
+# $Id: powerpoint.pl,v 1.6.4.7 2004/03/22 07:20:20 opengl2772 Exp $
 # Copyright (C) 2000 Ken-ichi Hirose, 
-#               2000 Namazu Project All rights reserved.
+#               2000,2002-2004 Namazu Project All rights reserved.
 #     This is free software with ABSOLUTELY NO WARRANTY.
 #
 #  This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,6 @@
 package powerpoint;
 use strict;
 use File::Basename;
-use File::Copy;
 require 'util.pl';
 require 'gfilter.pl';
 require 'html.pl';
@@ -76,7 +75,7 @@ sub post_codeconv () {
 sub add_magic ($) {
     my ($magic) = @_;
 
-    $magic->addFileExts('\\.ppt$', 'application/powerpoint');
+    $magic->addFileExts('\\.pp[st]$', 'application/powerpoint');
     return;
 }
 
@@ -85,7 +84,7 @@ sub filter ($$$$$) {
       = @_;
     my $err = undef;
 
-    if ($pptconvname =~ /ppthtml/i) {
+    if (defined $pptconvname && $pptconvname =~ /ppthtml/i) {
     $err = filter_ppt($orig_cfile, $cont, $weighted_str, $headings, $fields);
     } else {
     $err = filter_doccat($orig_cfile, $cont, $weighted_str, $headings, $fields);
@@ -107,6 +106,7 @@ sub filter_ppt ($$$$$) {
     {
 	my $fh = util::efopen("> $tmpfile");
 	print $fh $$cont;
+        util::fclose($fh);
     }
 
 #
@@ -117,6 +117,7 @@ sub filter_ppt ($$$$$) {
     {
 	my $fh = util::efopen("< $tmpfile2");
 	$$cont = util::readfile($fh);
+        util::fclose($fh);
     }
 
     # Code conversion for Japanese document.
@@ -130,11 +131,14 @@ sub filter_ppt ($$$$$) {
 	{
 	    my $fh = util::efopen("> $tmpfile");
 	    print $fh $$cont;
+            util::fclose($fh);
 	}
 	system("$utfconvpath -I$encoding -Oej $tmpfile > $tmpfile2");
 	{
 	    my $fh = util::efopen("< $tmpfile2");
 	    $$cont = util::readfile($fh);
+            util::fclose($fh);
+	    codeconv::normalize_eucjp($cont);
 	}
     } 
 
@@ -167,13 +171,18 @@ sub filter_doccat ($$$$$) {
 
     my $tmpfile  = util::tmpnam('NMZ.powerpoint');
     my $tmpfile2 = util::tmpnam('NMZ.powerpoint2');
-    copy("$cfile", "$tmpfile2");
+    {
+        my $fh = util::efopen("> $tmpfile2");
+        print $fh $$cont;
+        util::fclose($fh);
+    }
 
     system("$pptconvpath -o e $tmpfile2 > $tmpfile");
 
     {
         my $fh = util::efopen("< $tmpfile");
         $$cont = util::readfile($fh);
+        util::fclose($fh);
     }
 
     unlink($tmpfile);
