@@ -14,8 +14,8 @@
 #define nmz_iseuc_kana1st(c) ((uchar)(c) == 0x8e)
 #define nmz_iseuc_hojo1st(c) ((uchar)(c) == 0x8f)
 
-extern unsigned long nmz_scan_oct ( char *start, int len, int *retlen );
-extern unsigned long nmz_scan_hex ( char *start, int len, int *retlen );
+extern unsigned long nmz_scan_oct ( const char *start, int len, int *retlen );
+extern unsigned long nmz_scan_hex ( const char *start, int len, int *retlen );
 extern void * nmz_xmalloc ( unsigned long size );
 extern void * nmz_xrealloc ( void *ptr, unsigned long size );
 extern void nmz_tr ( char *str, const char *lstr, const char *rstr );
