@@ -1,9 +1,9 @@
 /*
- * $Id: result.c,v 1.59.8.9 2001/12/26 01:34:10 knok Exp $
+ * $Id: result.c,v 1.59.8.16 2004/03/20 15:02:51 usu Exp $
  * 
  * Copyright (C) 1989, 1990 Free Software Foundation, Inc.
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000 Namazu Project All rights reserved.
+ * Copyright (C) 2000-2004 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -134,7 +134,7 @@ replace_field(struct nmz_data d, int counter,
      * 8 is length of '&quot;' + 2 (for emphasizing). 
      * It's a consideration for buffer overflow (overkill?) 
      */
-    char buf[BUFSIZE * 8];  
+    char buf[BUFSIZE * 8] = "";  
 
     if (strcmp(field, "namazu::score") == 0) {
 	sprintf(buf, "%d", d.score);
@@ -175,7 +175,7 @@ static void
 encode_entity(char *str)
 {
     int i;
-    char tmp[BUFSIZE];
+    char tmp[BUFSIZE] = "";
 
     strncpy(tmp, str, BUFSIZE - 1);
     strcpy(str, "");
@@ -205,8 +205,11 @@ emphasize(char *str)
 
     for (i = 0; nmz_get_querytoken(i) != NULL; i++) {
 	char *ptr = str;
-	char key[BUFSIZE];
+	char key[BUFSIZE] = "";
 	int keylen = 0;
+        int findFlag = 0;
+        char *keys;
+        char *word;
 
 	if (nmz_is_query_op(nmz_get_querytoken(i)))
 	    continue;
@@ -215,10 +218,81 @@ emphasize(char *str)
 
 	if (strchr(key, '\t')) { /* for phrase search */
 	    nmz_tr(key, "\t", " ");
-	    strncpy(key, key + 1, BUFSIZE - strlen(key)); 
-	    key[strlen(key) - 1] = '\0';
+            memmove(key, key + 1, strlen(key + 1) + 1);
+            key[strlen(key) - 1] = '\0';
+
+            nmz_strlower(key);
+
+            ptr = str;
+            while (*ptr) {
+                char *lowerString, *lowerPtr;
+                char *startPos, *endPos;
+
+                lowerString = strdup(str);
+                nmz_strlower(lowerString);
+                lowerPtr = lowerString + (ptr - str);
+                startPos = endPos = lowerPtr;
+
+                findFlag = 0;
+                for (; *lowerPtr; lowerPtr++, ptr++) {
+                   keys = strdup(key);
+                   word = strtok(keys, " \t\n\r");
+                   if (!strncmp(lowerPtr, word, strlen(word))) {
+                       startPos = lowerPtr;
+                       endPos = lowerPtr + strlen(word);
+                       lowerPtr += strlen(word);
+                       ptr += strlen(word);
+                       findFlag = 1;
+                       while ((word = strtok(NULL, " \t\n\r"))) {
+                           while (*lowerPtr == ' ' || *lowerPtr == '\t' || *lowerPtr == '\r' || *lowerPtr == '\n') {
+                               lowerPtr++;
+                               ptr++;
+                           }
+                           if (!strncmp(lowerPtr, word, strlen(word))) {
+                               findFlag = 1;
+                               endPos = lowerPtr + strlen(word);
+                           }
+                           else {
+                               findFlag = 0;
+                               break;
+                           }
+                           lowerPtr += strlen(word);
+                           ptr += strlen(word);
+                       }
+                   }
+                   free(keys);
+
+                   if (findFlag) {
+                       break;
+                   }
+                }
+
+                free(lowerString);
+
+                if (!findFlag) {
+                    break;
+                }
+
+                keylen = endPos - startPos;
+                ptr -= keylen;
+                memmove(ptr + 2, ptr, strlen(ptr) + 1);
+                memmove(ptr + 1, ptr + 2, keylen);
+                *ptr = EM_START_MARK;
+                *(ptr + keylen + 1) = EM_END_MARK;
+                ptr += keylen + 2;
+            }
+            continue;
 	}
 
+        if (strlen(key) > 0) {
+            if ((key[0] == '"' && key[strlen(key) - 1] == '"')
+            || (key[0] == '{' && key[strlen(key) - 1] == '}')
+            || (key[0] == '/' && key[strlen(key) - 1] == '/')) {
+                memmove(key, key + 1, strlen(key + 1) + 1);
+                key[strlen(key) - 1] = '\0';
+            }
+        }
+
 	keylen = strlen(key);
 
 	do {
@@ -268,7 +342,7 @@ compose_result(struct nmz_data d, int counter,
 			   const char *template, char *r)
 {
     const char *p = template;
-    char achars[BUFSIZE]; /* acceptable characters */
+    char achars[BUFSIZE] = ""; /* acceptable characters */
 
     strcpy(r, "\t");  /* '\t' has an important role cf. html_print() */
 
@@ -284,7 +358,7 @@ compose_result(struct nmz_data d, int counter,
 	    pp += 2;  /* skip "${" */
 	    n = strspn(pp, achars);
 	    if (n > 0 && pp[n] == '}') {
-		char field[BUFSIZE];
+		char field[BUFSIZE] = "";
 		
 		strncpy(field, pp, n);
 		field[n] = '\0';
@@ -294,7 +368,7 @@ compose_result(struct nmz_data d, int counter,
 		p += 2;
 	    }
 	} else {
-	    strncat(r, p, BUFSIZE - strlen(r) - 1);
+	    strncat(r, p, BUFSIZE * 128 - strlen(r) - 1);
 	    break;
 	}
     } while (1);
